# QuickNotes

QuickNotes is a personal knowledge management application that allows you to create, manage, and interlink your notes, save articles for later reading, subscribe to RSS/Atom feeds, upload and view PDF documents, and perform a unified full-text search across all your content.

## Features

- **Notes**: Create, edit, and delete notes with Markdown support. Interlink notes using wiki-style syntax and visualize connections with an interactive graph.
- **Readlist**: Save and view articles for later reading with automatic content extraction.
- **Feeds**: Subscribe to and manage RSS/Atom feeds, and view feed entries with options to mark them as read or unread.
- **Documents**: Upload and view PDF documents directly within the app without needing to download them.
- **Omnisearch**: Perform unified full-text searches across notes, feed entries, readlist items, and documents.

## Technology Stack

- **Backend**: Go with the Gin web framework and GORM; SQLite for data storage.
- **Frontend**: Svelte with SvelteKit, styled with Bulma CSS and FontAwesome for icons.
- **Search**: Bleve for full-text search capabilities.
- **PDF Viewing**: Integrated PDF.js-like viewer for inline document viewing.
- **Package Management**: Bun for frontend dependencies and Go modules for backend dependencies.
- **Testing**: Go testing framework for backend and Playwright for end-to-end frontend testing.

## Installation

1. **Server Setup**:
   - Ensure Go is installed.
   - Build the backend server using `go build` or the provided `build.sh` script.
   - Ensure Bun is installed and run `bun install` in the frontend directory.
   - Start the backend server (default URL: `http://localhost:3000`).

2. **Frontend**:
   - The SvelteKit frontend is served by the Go backend after being built, or can be run separately for development.
   - Access the application via your web browser at `http://localhost:3000`.

## Usage

- Navigate using dedicated pages for Notes, Readlist, Feeds, Documents, and Omnisearch.
- Use the Omnisearch page to perform full-text searches across all content domains.

## Documentation

For detailed specifications, see:

- [Architecture](specs/architecture.md)
- [Notes](specs/notes.md)
- [Readlist](specs/readlist.md)
- [Feeds](specs/feeds.md)
- [Documents](specs/documents.md)
- [Omnisearch](specs/omnisearch.md)
- [Database](specs/database.md)
- [API](specs/api.md)
- [Frontend](specs/frontend.md)
- [Authentication](specs/authentication.md)
- [Links](specs/links.md)

## License

This project is licensed under the MIT License.
